pub struct Report { /* private fields */ }Expand description
Comparison report for newly generated artifacts versus the artifacts stored in
artifacts_subdir.
Implementations
Sourceimpl Report
impl Report
Sourcepub fn assert_unregressed(self)
pub fn assert_unregressed(self)
If any mismatches were found, this function will iterate through and print info about them to stdout, before panicking.